# sob

[![test](https://github.com/enorganic/sob/actions/workflows/test.yml/badge.svg)](https://github.com/enorganic/sob/actions/workflows/test.yml)
[![distribute](https://github.com/enorganic/sob/actions/workflows/distribute.yml/badge.svg)](https://github.com/enorganic/sob/actions/workflows/distribute.yml)

`sob` is an object serialization/deserialization library intended to facilitate
authoring of API models which are readable and introspective, and to expedite
code and data validation and testing.
